@@ -31,6 +31,7 @@ ORDER = [
     'pool_read_operations',
     'pool_write_operations',
     'osd_usage',
+    'osd_size',
     'osd_apply_latency',
     'osd_commit_latency'
 ]
@@ -101,6 +102,10 @@ CHARTS = {
         'options': [None, 'Ceph OSDs', 'KiB', 'osd', 'ceph.osd_usage', 'line'],
         'lines': []
     },
+    'osd_size': {
+        'options': [None, 'Ceph OSDs size', 'KiB', 'osd', 'ceph.osd_size', 'line'],
+        'lines': []
+    },
     'osd_apply_latency': {
         'options': [None, 'Ceph OSDs apply latency', 'milliseconds', 'osd', 'ceph.apply_latency', 'line'],
         'lines': []
@@ -189,6 +194,9 @@ class Service(SimpleService):
             self.definitions['osd_usage']['lines'].append([osd['name'],
                                                            osd['name'],
                                                            'absolute'])
+            self.definitions['osd_size']['lines'].append(['size_{0}'.format(osd['name']),
+                                                           osd['name'],
+                                                           'absolute'])
             self.definitions['osd_apply_latency']['lines'].append(['apply_latency_{0}'.format(osd['name']),
                                                                    osd['name'],
                                                                    'absolute'])
@@ -217,6 +225,7 @@ class Service(SimpleService):
                 data.update(self._get_pool_rw(pool_io))
             for osd in osd_df['nodes']:
                 data.update(self._get_osd_usage(osd))
+                data.update(self._get_osd_size(osd))
             for osd_apply_commit in osd_perf_infos:
                 data.update(self._get_osd_latency(osd_apply_commit))
             return data
@@ -295,6 +304,14 @@ class Service(SimpleService):
         """
         return {osd['name']: float(osd['kb_used'])}
 
+    @staticmethod
+    def _get_osd_size(osd):
+        """
+        Process raw data into osd dict information to get osd size (kb)
+        :return: A osd dict with osd name's key and size bytes' value
+        """
+        return {'size_{0}'.format(osd['name']): float(osd['kb'])}
+
     @staticmethod
     def _get_osd_latency(osd):
         """
@@ -314,7 +331,7 @@ class Service(SimpleService):
         return json.loads(self.cluster.mon_command(json.dumps({
             'prefix': 'df',
             'format': 'json'
-        }), '')[1].decode('utf-8'))
+        }), b'')[1].decode('utf-8'))
 
     def _get_osd_df(self):
         """
@@ -324,7 +341,7 @@ class Service(SimpleService):
         return json.loads(self.cluster.mon_command(json.dumps({
             'prefix': 'osd df',
             'format': 'json'
-        }), '')[1].decode('utf-8').replace('-nan', '"-nan"'))
+        }), b'')[1].decode('utf-8').replace('-nan', '"-nan"'))
 
     def _get_osd_perf(self):
         """
@@ -334,7 +351,7 @@ class Service(SimpleService):
         return json.loads(self.cluster.mon_command(json.dumps({
             'prefix': 'osd perf',
             'format': 'json'
-        }), '')[1].decode('utf-8'))
+        }), b'')[1].decode('utf-8'))
 
     def _get_osd_pool_stats(self):
         """
@@ -346,7 +363,7 @@ class Service(SimpleService):
         return json.loads(self.cluster.mon_command(json.dumps({
             'prefix': 'osd pool stats',
             'format': 'json'
-        }), '')[1].decode('utf-8'))
+        }), b'')[1].decode('utf-8'))
 
 
 def get_osd_perf_infos(osd_perf):
